also prevent it in .htacces. You may want to add this to one of your files in /etc...
[mailer.git] / agb.php
diff --git a/agb.php b/agb.php
index f564e7bd4d5c63c031ded0aff6026328ddc043f1..5cadca9b3c7eef475e0351dcd0b9573970efd1ed 100644 (file)
--- a/agb.php
+++ b/agb.php
@@ -1,7 +1,7 @@
 <?php
 /************************************************************************
- * MXChange v0.2.1                                    Start: 11/27/2003 *
- * ===============                              Last change: 04/26/2004 *
+ * Mailer v0.2.1-FINAL                                Start: 11/27/2003 *
+ * ===================                          Last change: 04/26/2004 *
  *                                                                      *
  * -------------------------------------------------------------------- *
  * File              : agb.php                                          *
  * -------------------------------------------------------------------- *
  * Kurzbeschreibung  : Allgemeine Geschaeftsbedingungen                 *
  * -------------------------------------------------------------------- *
- * $Revision:: 856                                                    $ *
- * $Date:: 2009-03-06 20:24:32 +0100 (Fr, 06. Mär 2009)              $ *
- * $Tag:: 0.2.1-FINAL                                                 $ *
- * $Author:: stelzi                                                   $ *
- * Needs to be in all Files and every File needs "svn propset           *
- * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
- * -------------------------------------------------------------------- *
- * Copyright (c) 2003 - 2008 by Roland Haeder                           *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2003 - 2009 by Roland Haeder                           *
+ * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
  * MA  02110-1301  USA                                                  *
  ************************************************************************/
 
-// Load security stuff here (Oh, I hope this is not unsecure? Am I paranoia??? ;-) )
-require("inc/libs/security_functions.php");
+// Load security stuff here
+require('inc/libs/security_functions.php');
+
+// Init start time
+$GLOBALS['__start_time'] = microtime(TRUE);
 
-// Init "action" and "what"
-$GLOBALS['what'] = "";
-$GLOBALS['action'] = "";
+// Set module and output mode (raw)
+$GLOBALS['__module']      = 'agb';
+$GLOBALS['__output_mode'] = -1;
 
-// Set module
-$GLOBALS['module'] = "agb";
-$GLOBALS['output_mode'] = -1;
+// Initialize application
+require('inc/init.php');
 
-// Load the required file(s)
-require("inc/config.php");
+// Set content type for e.g. search engines
+setContentType('text/html');
 
-// Is the script installed?
-if (isInstalled()) {
-       // Simply redirect... :-)
-       LOAD_URL("modules.php?module=index&amp;what=agb");
-} else {
-       // You have to install first!
-       LOAD_URL("install.php");
-}
+// Simply redirect... :-)
+redirectToUrl('modules.php?module=index&amp;what=agb');
 
-// Really all done here... ;-)
+// [EOF]
 ?>